@@ -18,6 +18,7 @@ import yaml
 import warnings
 import urllib.parse
 import shutil
+import threading
 
 from .exceptions import DSLibraryDataFormatException, DSLibraryException
 from .engine_intf import GenericStreamWrapper, BytesIOWrapper
@@ -57,6 +58,9 @@ PARAMS_ALIAS = "__params__"
 # pass/fail signal from model evaluation actions
 EVALUATION_RESULT_ALIAS = "__evaluation_result__"
 
+# override specification for a given thread
+THREAD_SPEC = threading.local()
+
 
 class DSLibrary(object):
     """
@@ -73,7 +77,7 @@ class DSLibrary(object):
                         methods to MLFlow.
         """
         self._params = None
-        self._spec = spec or {}
+        self._spec_ = spec or {}
         self._env = _env
         spec_wo_data = dict(self._spec)
         spec_wo_data.pop("data", None)
@@ -87,6 +91,12 @@ class DSLibrary(object):
         self._mlflow_run = None
         self._setup_code_paths()
 
+    @property
+    def _spec(self) -> dict:
+        if hasattr(THREAD_SPEC, "value"):
+            return THREAD_SPEC.value
+        return self._spec_
+
     def _setup_code_paths(self):
         """
         A list of folders containing required modules can be specified.
@@ -134,7 +144,8 @@ class DSLibrary(object):
         Parameter values come from supplied specifications (see constructor), or if omitted, we fall back to the command
         line.
         """
-        if self._params is None:
+        threaded = hasattr(THREAD_SPEC, "value")
+        if self._params is None or threaded:
             # check local specifications, then check environment and command line
             params = self._spec.get("parameters")
             # fall back to CLI parameters
@@ -147,6 +158,8 @@ class DSLibrary(object):
                 for param_name, param_props in entry_point.parameters.items():
                     params[param_name] = param_props.process_value(params.get(param_name))
             # cache the parameter values
+            if threaded:
+                return params
             self._params = params
         return self._params
 
@@ -675,6 +688,11 @@ class DSLibrary(object):
                         with opener(uri, 'wb', **kwargs) as f_w:
                             shutil.copyfileobj(f_r, f_w)
                 return
+            # pandas does not support writing to streams for HDF files
+            if format == "hdf":
+                # FIXME we are bypassing opener() here, which could be problematic
+                df_method(uri, **format_options, **kwargs)
+                return
             compression = format_options.pop("compression", None)
             if compression:
                 mode += "b"
