@@ -7,7 +7,6 @@ import io
 import json
 import inspect
 
-from dslibrary.engine_intf import FileSystem
 from dslibrary.front import DSLibraryException
 from dslibrary.metadata import Metadata
 from dslibrary.utils.file_utils import write_stream_with_read_on_close, FileOpener
@@ -51,14 +50,26 @@ class DSLibraryViaMMLibrary(DSLibrary):
 
     def get_parameters(self):
         if not self._mm:
-            return {}
-        get_arguments = self._find_method("get_arguments", "get_parameters", mandatory=False)
-        if get_arguments:
-            return self._mm.get_arguments()
-        if hasattr(self._mm, "param_dictionary"):
-            return self._mm.param_dictionary
-        raise DSLibraryException(f"method not found: get_arguments()")
+            mm_params = {}
+        else:
+            get_arguments = self._find_method("get_arguments", "get_parameters", mandatory=False)
+            if get_arguments:
+                mm_params = self._mm.get_arguments()
+            elif hasattr(self._mm, "param_dictionary"):
+                mm_params = self._mm.param_dictionary
+            else:
+                raise DSLibraryException(f"method not found: get_arguments()")
+        # 'spec_params' take precedence over 'mm_params':
+        #   - mm_params should be honored most of the time, but...
+        #   - spec_params come from a supplied specification, i.e. from environment variables (see ModelRunner)
+        #   - sometimes 'mm_params' are just defaults
+        #   - in any case, environment-based parameters are 'more explicit'
+        out = dict(mm_params)
+        spec_params = super(DSLibraryViaMMLibrary, self).get_parameters()
+        out.update(spec_params)
+        return out
 
+    '''
     def get_parameter(self, parameter_name: str, default=None):
         if not self._mm:
             return default
@@ -68,6 +79,7 @@ class DSLibraryViaMMLibrary(DSLibrary):
         except (ValueError, KeyError):
             pass
         return default
+    '''
 
     def _opener(self, path: str, mode: str, **kwargs) -> io.IOBase:
         """
