@@ -63,6 +63,9 @@ class FileOpener(object):
             return
         if not fsspec:
             raise ImportWarning(f"The 'fsspec' package is required to open {path}")
+        kwargs = adapt_fsspec_storage_options(kwargs)
+        if "storage_options" in kwargs:
+            kwargs = kwargs["storage_options"]
         return fsspec.open(path, mode=mode, **kwargs)
 
     def local_open(self, path: str, mode: str, **kwargs):
@@ -142,3 +145,31 @@ def connect_to_filesystem(uri: str, for_write: bool=False, **kwargs):
     if not for_write:
         return FileSystemReadOnly(fs)
     return fs
+
+
+def adapt_fsspec_storage_options(opts: dict) -> dict:
+    """
+    Adapt named arguments to work with fsspec.open().
+
+    :param opts:  A 'kwargs' set of named parameters with either 'storage_options: dict', or parameters like
+                    'access_key'.
+
+    :returns:  A {} with options named as fsspec.open() expects, i.e. {"storage_options": {"key": "xyz"}} instead of
+                access_key="xyz"
+    """
+    opts = dict(opts)
+    storage_options = opts.pop("storage_options", None) or {}
+    for k, k2 in KNOWN_FSSPEC_STORAGE_OPTIONS.items():
+        if k in opts:
+            storage_options[k2] = opts.pop(k)
+        if k2 in opts:
+            storage_options[k2] = opts.pop(k2)
+    if storage_options:
+        opts["storage_options"] = storage_options
+    return opts
+
+
+KNOWN_FSSPEC_STORAGE_OPTIONS = {
+    "access_key": "key", "secret_key": "secret", "service_account": "service_account",
+    "account_name": "account_name", "account_key": "account_key"
+}
\ No newline at end of file
