@@ -379,11 +379,12 @@ class TestFront(unittest.TestCase):
         changes.
         """
         inst = DSLibrary()
-        inst._spec = {"code_paths": ["a", "b"]}
+        inst._spec_ = {"code_paths": ["a", "b"]}
+        self.assertEqual(inst._spec, {"code_paths": ["a", "b"]})
         mock_paths = []
         with mock.patch("sys.path", mock_paths):
             inst._setup_code_paths()
-        self.assertEqual(mock_paths, ["a", "b"])
+        self.assertEqual(["a", "b"], mock_paths)
 
     def test_abstract_base_methods(self):
         """
